=========
Changelog
=========

0.9.6 (2019-05-26)
------------------
* Python 3.6 and 3.7 compatibility
* Update Onix 3 to Revision 6 and Code List issue 45

0.9.5 (2016-08-19)
------------------
* Update Onix 3 to Code List issue 34
* Remove build artifacts from source distribution

0.9.4 (2016-07-15)
------------------
* Fix issue with windows console output encoding
* Update windows build to pyinstaller 3.1

0.9.3 (2016-05-10)
------------------
* Update ONIX 3.0 Schemas to Revision 3
* Add support for RELAX NG and custom schema validations
* Added validator name to short message output

0.9.2 (2016-04-11)
------------------
* Fix ExtentType in custom validation profile
* Fix false alarm with multiple Price elements in custom profile

0.9.1 (2016-04-11)
------------------
* Inital support for custom validation profiles
* Custom Google Play Books onix 3.0 validation profile

0.9.0 (2016-03-27)
------------------

* Added Python 3.5 testing / support
* Update to ONIX to Code List Issue 32 / 2016-01-24

0.8.1 (2015-07-23)
------------------

* More extensive documentation

0.8.0 (2015-07-23)
------------------

* Added CLI-support for fast directory traversal validation
* Secured XML-Parsing via defusedxml
* Catch basic XML syntax errors
* Windows standalone binary builds

0.4.0 (2015-07-18)
------------------

* First release on PyPI.
